/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.actions;

import org.apache.log4j.Logger;
import org.eclipse.ui.IWorkbenchWindow;
import org.eclipse.ui.actions.ActionFactory;
import org.eclipse.ui.actions.NewWizardAction;
import org.eclipse.ui.actions.ActionFactory.IWorkbenchAction;

import eu.etaxonomy.taxeditor.actions.ui.OpenTaxonEditorAction;

/**
 * This class is an extension to the standard ActionFactory. Any useful
 * functionality already implemented in ActionFactory may be used or 
 * overwritten by more suitable implementations.
 * 
 * @author n.hoffmann
 * @created 03.02.2009
 * @version 1.0
 */
public abstract class TaxEditorActionFactory extends ActionFactory {
	private static final Logger logger = Logger
			.getLogger(TaxEditorActionFactory.class);
	
    /**
     * Workbench action (id "new"): Opens the new wizard dialog. This action maintains
     * its enablement state.
     */
    public static final ActionFactory NEW = new ActionFactory("new") {//$NON-NLS-1$
        
        /* (non-Javadoc)
         * @see org.eclipse.ui.actions.ActionFactory#create(org.eclipse.ui.IWorkbenchWindow)
         */
        public IWorkbenchAction create(IWorkbenchWindow window) {
            if (window == null) {
                throw new IllegalArgumentException();
            }
            IWorkbenchAction action = new OpenTaxonEditorAction();
            action.setId(getId());
            return action;
        }
    };
	
    /**
     * Creates a new workbench action factory with the given id.
     * 
     * @param actionId
     *            the id of actions created by this action factory
     */
    protected TaxEditorActionFactory(String actionId) {
        super(actionId);
    }
}
