/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.handlers;

import org.apache.log4j.Logger;
import org.eclipse.core.commands.AbstractHandler;
import org.eclipse.core.commands.ExecutionEvent;
import org.eclipse.core.commands.ExecutionException;
import org.eclipse.core.commands.IHandler;
import org.eclipse.ui.IEditorInput;
import org.eclipse.ui.IEditorPart;

import eu.etaxonomy.cdm.model.taxon.Taxon;
import eu.etaxonomy.taxeditor.actions.cdm.SaveTaxonAction;
import eu.etaxonomy.taxeditor.controller.EditorController;
import eu.etaxonomy.taxeditor.datasource.CdmTransactionController;
import eu.etaxonomy.taxeditor.editor.MultiPageTaxonEditor;
import eu.etaxonomy.taxeditor.model.CdmSessionDataRepository;

/**
 * @author n.hoffmann
 * @created 06.02.2009
 * @version 1.0
 */
public class SaveAllHandler extends AbstractHandler implements IHandler {
	private static final Logger logger = Logger.getLogger(SaveAllHandler.class);

	/* (non-Javadoc)
	 * @see org.eclipse.core.commands.IHandler#execute(org.eclipse.core.commands.ExecutionEvent)
	 */
	public Object execute(ExecutionEvent event) throws ExecutionException {
		logger.debug("Save all handler called.");
		EditorController.setSaving(true);
		
		// Get all open windows
		for (IEditorPart taxonEditor : EditorController.getOpenEditors()) {

			// Save the dirty ones
			if (taxonEditor.isDirty()) {
				IEditorInput input = taxonEditor.getEditorInput();
				if (input.getAdapter(Taxon.class) != null) {
					Taxon taxon = (Taxon) input.getAdapter(Taxon.class);
					new SaveTaxonAction(taxon).run();
					if (taxonEditor instanceof MultiPageTaxonEditor) {
						((MultiPageTaxonEditor) taxonEditor).setDirtyExtern(false);
					}
				}
			}
		}

		// Commit the transaction	
		CdmTransactionController.commitTransaction();
	
		// Force library objects to be associated with new transaction
		CdmSessionDataRepository.getDefault().clearNonTaxonData();
		
		// Start a new transaction
		CdmTransactionController.startTransaction();
		
		// Put all open taxa in the new transaction
		CdmTransactionController.addSessionTaxaToTransaction();
		
		EditorController.setSaving(false);
		// TODO: delete undoHistory
		return null;
	}
}
