/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.navigation;

import org.apache.log4j.Logger;
import org.eclipse.jface.action.IToolBarManager;
import org.eclipse.jface.viewers.ArrayContentProvider;
import org.eclipse.jface.viewers.DoubleClickEvent;
import org.eclipse.jface.viewers.IDoubleClickListener;
import org.eclipse.jface.viewers.LabelProvider;
import org.eclipse.jface.viewers.StructuredSelection;
import org.eclipse.jface.viewers.TableViewer;
import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.ui.part.ViewPart;

import eu.etaxonomy.cdm.model.common.IdentifiableEntity;
import eu.etaxonomy.cdm.model.name.TaxonNameBase;
import eu.etaxonomy.cdm.model.taxon.Synonym;
import eu.etaxonomy.cdm.model.taxon.Taxon;
import eu.etaxonomy.cdm.model.taxon.TaxonBase;
import eu.etaxonomy.taxeditor.controller.EditorController;

/**
 * @author p.ciardelli
 * @created 19.01.2009
 * @version 1.0
 */
public class SearchResultView extends ViewPart {
	private static final Logger logger = Logger
			.getLogger(SearchResultView.class);

	public static final String ID = "eu.etaxonomy.taxeditor.navigation.searchresultview"; //$NON-NLS-1$

	private TableViewer resultViewer;
	
	/* (non-Javadoc)
	 * @see org.eclipse.ui.part.WorkbenchPart#createPartControl(org.eclipse.swt.widgets.Composite)
	 */
	@Override
	public void createPartControl(Composite parent) {
		resultViewer = new TableViewer(parent, SWT.BORDER);
		resultViewer.setContentProvider(new ArrayContentProvider());
		resultViewer.setLabelProvider(new LabelProvider() {
			public String getText(Object element) {
				if (element instanceof IdentifiableEntity) {
					if(element instanceof TaxonBase){
						// TODO we want to stylize the text (color, font-style etc.)
						if(element instanceof Taxon){
							return "Taxon: " + ((TaxonBase) element).getTitleCache();
						}else{
							return "Synonym: " + ((TaxonBase) element).getTitleCache();
						}
					}else{
						return "Name: " + super.getText(element);
					}
				}
				return super.getText(element);
			}
		});
		resultViewer.addDoubleClickListener(new IDoubleClickListener() {
			public void doubleClick(DoubleClickEvent event) {
				TaxonBase taxonBase = null;
				try {
					
					IdentifiableEntity selection = (IdentifiableEntity) ((StructuredSelection) event.getSelection()).getFirstElement();
					
					if(selection instanceof TaxonBase){
						EditorController.openTaxonEditor((TaxonBase) selection);
					}
				} catch (Exception e) {
					logger.error("Error opening editor from search result", e);
				}
			}
		});
	}

	/* (non-Javadoc)
	 * @see org.eclipse.ui.part.WorkbenchPart#setFocus()
	 */
	@Override
	public void setFocus() {

	}
	private void initializeToolBar() {
		IToolBarManager toolBarManager = getViewSite().getActionBars().getToolBarManager();
	}

	public void setResult(SearchResult searchResult) {
		resultViewer.setInput(searchResult); 
		setPartName("Search: '" + searchResult.getSearchString() + "'");
	}
}
