/**
 * Copyright (C) 2007 EDIT
 * European Distributed Institute of Taxonomy 
 * http://www.e-taxonomy.eu
 * 
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * See LICENSE.TXT at the top of this package for the full license terms.
 */

package eu.etaxonomy.taxeditor.propertysheet.namerelations.wizard;

import java.beans.PropertyChangeListener;
import java.beans.PropertyChangeSupport;
import java.util.List;

import org.apache.log4j.Logger;

import eu.etaxonomy.cdm.model.name.NameRelationship;
import eu.etaxonomy.cdm.model.name.NameRelationshipType;
import eu.etaxonomy.cdm.model.name.TaxonNameBase;
import eu.etaxonomy.cdm.model.name.ZoologicalName;
import eu.etaxonomy.taxeditor.model.CdmUtil;

/**
 * @author p.ciardelli
 * @created 05.06.2008
 * @version 1.0
 */
public class NameRelationWizardModel {
	private static final Logger logger = Logger
			.getLogger(NameRelationWizardModel.class);

	protected static final String RELATEDNAME = "relatedname";
	protected static final String RELATIONTYPE = "relationtype";

	private TaxonNameBase baseName;
	private TaxonNameBase relatedName;
	private TaxonNameBase fromName;
	private TaxonNameBase toName;
	private NameRelationshipType type;
	private boolean isZoological = false;
	
	// Stores pre-existing relation, if any exists
	private NameRelationship nameRelationship;
	// List of the base name's relations
	private List<NameRelationship> nameRelationsList; 

	private PropertyChangeSupport propertyChangeSupport;


	public NameRelationWizardModel(TaxonNameBase baseName) {
		this.baseName = baseName;
		if (baseName instanceof ZoologicalName) {
			isZoological = true;
		}
		this.propertyChangeSupport = new PropertyChangeSupport(this);
	}

	private void firePropertyChange(String propertyName, Object oldValue,
			Object newValue) {
		propertyChangeSupport.firePropertyChange(propertyName, oldValue,
				newValue);
	}

	public void addPropertyChangeListener(String propertyName,
			PropertyChangeListener listener) {
		propertyChangeSupport.addPropertyChangeListener(propertyName, listener);
	}

	public void addPropertyChangeListener(PropertyChangeListener listener) {
		propertyChangeSupport.addPropertyChangeListener(listener);
	}

	public TaxonNameBase getBaseName() {
		return baseName;
	}

	public void setBaseName(TaxonNameBase baseName) {
		this.baseName = baseName;
	}

	public TaxonNameBase getRelatedName() {
		return relatedName;
	}

	public void setRelatedName(TaxonNameBase relatedName) {
		this.relatedName = relatedName;
		firePropertyChange(RELATEDNAME, null, relatedName);
	}

	public TaxonNameBase getFromName() {
		return fromName;
	}

	public void setFromName(TaxonNameBase fromName) {
		this.fromName = fromName;
		logger.warn("Setting from name: " + CdmUtil.getDisplayName(fromName));
	}

	public TaxonNameBase getToName() {
		return toName;
	}

	public void setToName(TaxonNameBase toName) {
		this.toName = toName;
		logger.warn("Setting to name: " + CdmUtil.getDisplayName(toName));
	}

	public NameRelationshipType getType() {
		return type;
	}

	public void setType(NameRelationshipType type) {
		this.type = type;
		firePropertyChange(RELATIONTYPE, null, type);
	}

	public void setRelation(NameRelationship nameRelationship) {
		this.nameRelationship = nameRelationship;		
	}

	public NameRelationship getRelation() {
		return nameRelationship;		
	}
	
	public void setNameRelationsList(List<NameRelationship> nameRelationsList) {
		this.nameRelationsList = nameRelationsList;
	}
	
	public List<NameRelationship> getNameRelationsList() {
		return nameRelationsList;
	}

	public boolean isZoological() {
		return isZoological;
	}
}
