/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.editor;

import org.apache.log4j.Logger;
import org.eclipse.swt.SWT;
import org.eclipse.swt.dnd.DND;
import org.eclipse.swt.dnd.DropTarget;
import org.eclipse.swt.dnd.DropTargetAdapter;
import org.eclipse.swt.dnd.DropTargetEvent;
import org.eclipse.swt.dnd.DropTargetListener;
import org.eclipse.swt.dnd.Transfer;
import org.eclipse.swt.graphics.Color;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Event;
import org.eclipse.swt.widgets.Listener;
import org.eclipse.ui.forms.widgets.TableWrapData;
import org.eclipse.ui.forms.widgets.TableWrapLayout;

import eu.etaxonomy.cdm.model.taxon.Taxon;
import eu.etaxonomy.taxeditor.model.Resources;

/**
 * @author p.ciardelli
 * @created 25.06.2008
 * @version 1.0
 */
public class GroupComposite extends Composite {
	private static final Logger logger = Logger.getLogger(GroupComposite.class);
	
	protected AbstractTaxonEditor editor;
	protected Taxon taxon;
	
	private DropTarget target;
	private DropTargetListener dropListener;
		
	public GroupComposite(Composite parent) {
		super(parent, SWT.NONE);

		// Graphic layout of composite
		this.setLayoutData(new TableWrapData(TableWrapData.FILL_GRAB));
		this.setLayout(new TableWrapLayout());
		Color groupBackgroundColor = Resources.
				getColor(Resources.COLOR_COMPOSITE_BACKGROUND);
		this.setBackground(groupBackgroundColor);

		// Drop functionality
		this.setDroppable(true);
		
		logger.trace("Created a new Group composite");
	}
	
	public GroupComposite(AbstractTaxonEditor editor, Composite parent){
		this(parent);
		this.editor = editor;
		this.taxon = editor.getTaxon();
	}
	
	public void setDroppable(boolean droppable) {
		if (droppable) {
			Transfer[] types = new Transfer[] {WidgetTransfer.getInstance()};	
			int operations = DND.DROP_MOVE | DND.DROP_COPY | DND.DROP_DEFAULT;
			target = new DropTarget(this, operations);
			target.setTransfer(types);
			dropListener = new DropTargetAdapter() {
							
				public void dragEnter(DropTargetEvent event) {
					GroupComposite.this.notifyListeners(SWT.FocusIn, null);
				}
				
				public void dragLeave(DropTargetEvent event) {
					GroupComposite.this.notifyListeners(SWT.FocusOut, null);
				}
				
				public void drop(DropTargetEvent event) {
									
					if (event.data instanceof GroupedComposite) {
						
						final GroupedComposite composite = (GroupedComposite) event.data;
						if (composite.getDragSource() != null) {
							
							// Make sure composite is not being dropped onto its current parent
							if ( ! composite.getParent().equals(GroupComposite.this)) {
								
								// Change parent at end of drag event
								composite.getDragSource().addListener(DND.DragEnd, new Listener() {
									
									public void handleEvent(Event event) {
										composite.setParent(GroupComposite.this);
									}
								});
							}							
						}
					}
				}
			};
			target.addDropListener(dropListener);			
		} else {
			if (dropListener != null) {
				target.removeDropListener(dropListener);
			}
		}
	}
	
	public void dispose() {
		
		if (target != null) {
			target.removeDropListener(dropListener);
			target.dispose();
		}
				
		super.dispose();
	}

	/**
	 * @return the taxon
	 */
	public Taxon getTaxon() {
		return taxon;
	}
}
