/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.editor.handler;

import java.util.Set;

import org.apache.log4j.Logger;
import org.eclipse.core.commands.AbstractHandler;
import org.eclipse.core.commands.ExecutionEvent;
import org.eclipse.core.commands.ExecutionException;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.ui.handlers.HandlerUtil;

import eu.etaxonomy.cdm.model.name.TaxonNameBase;
import eu.etaxonomy.cdm.model.taxon.Taxon;
import eu.etaxonomy.cdm.model.taxon.TaxonBase;
import eu.etaxonomy.cdm.model.taxon.TaxonRelationship;
import eu.etaxonomy.taxeditor.editor.EditorUtil;
import eu.etaxonomy.taxeditor.editor.MultiPageTaxonEditor;
import eu.etaxonomy.taxeditor.editor.name.IterableSynonymyList;

/**
 * @author n.hoffmann
 * @created 23.03.2009
 * @version 1.0
 */
public class SaveTaxonHandler extends AbstractHandler {
	private static final Logger logger = Logger
			.getLogger(SaveTaxonHandler.class);

	/* (non-Javadoc)
	 * @see org.eclipse.core.commands.IHandler#execute(org.eclipse.core.commands.ExecutionEvent)
	 */
	public Object execute(ExecutionEvent event) throws ExecutionException {

		MultiPageTaxonEditor editor = EditorUtil.getActiveEditor();
		// check for non zero length of taxon name
		if(isNameZeroLength(editor.getTaxon().getName())){			
			MessageDialog.openWarning(HandlerUtil.getActiveShell(event), "No Name Specified", "An attempt was made to save a taxon with " +
			"an empty name. Operation was cancelled.");
			return null;
		}
		
		if (!areRelatedNamesNonZeroLength(editor.getTaxon())) {
			MessageDialog.openWarning(HandlerUtil.getActiveShell(event), "Zero-Length Name", "One of this taxon's relationships " +
			"has a zero-length name. Operation was cancelled.");
			logger.trace("Tero length name detected.");
			return null;
		}
		
		return EditorUtil.getActivePage().saveEditor(editor, false);
		
	}

	/**
	 * @param name
	 * @return
	 */
	private boolean isNameZeroLength(TaxonNameBase<?, ?> name) {
		if (name == null) {
			return true;
		}
		return (name.getFullTitleCache().length() == 0);
	}

	/**
	 * @param taxon
	 * @return
	 */
	private boolean areRelatedNamesNonZeroLength(Taxon taxon) {
		for (TaxonBase<?> taxonBase : new IterableSynonymyList(taxon)) {
			if (isNameZeroLength(taxonBase.getName()) ) {
				return false;
			}
		}
		Set<TaxonRelationship> taxonRelations = taxon.getTaxonRelations();
		for (TaxonRelationship relationship : taxonRelations) {
			if (isNameZeroLength(relationship.getToTaxon().getName()) ||
					isNameZeroLength(relationship.getFromTaxon().getName())) {
				return false;
			}
		}	
		return true;
	}
}
