/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.editor.name;

import org.apache.log4j.Logger;
import org.eclipse.core.commands.operations.IUndoableOperation;
import org.eclipse.swt.graphics.Font;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.ui.views.properties.IPropertySource;

import eu.etaxonomy.cdm.model.name.HomotypicalGroup;
import eu.etaxonomy.cdm.model.name.TaxonNameBase;
import eu.etaxonomy.cdm.model.taxon.Synonym;
import eu.etaxonomy.taxeditor.editor.EditorUtil;
import eu.etaxonomy.taxeditor.model.NameUtil;
import eu.etaxonomy.taxeditor.operations.ChangeHomotypicGroupOperation;
import eu.etaxonomy.taxeditor.operations.ChangeSynonymToMisapplicationOperation;
import eu.etaxonomy.taxeditor.propertysheet.name.SynonymPropertySource;

/**
 * @author p.ciardelli
 * @created 13.01.2009
 * @version 1.0
 */
public class SynonymComposite extends NameComposite {
	@SuppressWarnings("unused")
	private static final Logger logger = Logger
			.getLogger(SynonymComposite.class);
	
	private Synonym synonym;
	
	public SynonymComposite(TaxonNameEditor editor, Composite parent, Synonym synonym) {
		super(editor, parent, null, synonym);
		
		this.taxon = editor.getTaxon();
		this.synonym = synonym;
		
		setIsDraggable(true);
		setFont(getViewerFont());
		setIndent(SYNONYM_INDENT);
		
		if (isHomotypic()) {
			if (NameUtil.isNameGroupBasionym(synonym.getName())) {
				setIcon(HOMOTYPIC_SYNONYM_ORIGINAL_COMBINATION_ICON);
			} else {
				setIcon(HOMOTYPIC_SYNONYM_ICON);
			}	
		} else {
			if (NameUtil.isNameGroupBasionym(synonym.getName())) {
				setIcon(HETEROTYPIC_SYNONYM_ORIGINAL_COMBINATION_ICON);
			} else {
				setIcon(HETEROTYPIC_SYNONYM_ICON);
			}
		}
		
		initTextViewer(synonym);
	}
	
	private boolean isHomotypic() {
		HomotypicalGroup group = synonym.getHomotypicGroup();
		return group.equals(taxon.getHomotypicGroup()); 
	}
	
	public Synonym getSynonym() {
		return synonym;
	}

	public boolean setParent(Composite parent) {

		boolean doSetParent = false;			
			
		// Has this been moved to the misapplied names group?
		if (parent instanceof MisappliedGroupComposite) {
			IUndoableOperation operation = new ChangeSynonymToMisapplicationOperation
					("change to misapplication", editor.getUndoContext(), taxon, synonym, editor); //$NON-NLS-1$
			EditorUtil.executeOperation(operation);
			
			doSetParent = true;
		}

		// Has this been moved to a HomotypicalGroup?
		if (parent instanceof HomotypicalGroupComposite) {
			
			HomotypicalGroup homotypicalGroup = 
					((HomotypicalGroupComposite)parent).getGroup();
			
			// Make sure we are not dropping synonym on its own group
			if (!homotypicalGroup.equals(synonym.getHomotypicGroup())) {
				IUndoableOperation operation = new ChangeHomotypicGroupOperation
						("change type", editor.getUndoContext(), taxon, synonym, homotypicalGroup, editor); //$NON-NLS-1$
				EditorUtil.executeOperation(operation);
				
				doSetParent = true;
			}
		}
		return doSetParent;
	}
		
	public IPropertySource getPropertySource() {
		if (NameUtil.isNameGroupBasionym(synonym.getName())) {
			return new BasionymSynonymPropertySource(synonym);
		} else {
			return new SynonymPropertySource(synonym);
		}
	}

	protected Font getViewerFont() {
		return SYNONYM_FONT;
	}

	@Override
	protected TaxonNameBase<?, ?> getName() {
		return synonym.getName();
	}
	
	public Object getData () {
		return getSynonym();
	}
}