// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.propertysheet.description;

import java.util.List;

import org.apache.log4j.Logger;
import org.eclipse.ui.views.properties.ComboBoxPropertyDescriptor;

import eu.etaxonomy.cdm.model.common.Language;
import eu.etaxonomy.cdm.model.description.CommonTaxonName;
import eu.etaxonomy.taxeditor.model.LanguageUtil;
import eu.etaxonomy.taxeditor.store.CdmStore;

/**
 * @author p.ciardelli
 * @created 02.04.2009
 * @version 1.0
 */
public class CommonNamePropertySource extends DescriptionElementPropertySource {
	private static final Logger logger = Logger
			.getLogger(CommonNamePropertySource.class);

	public static final String P_ID_LANGUAGE = "language";
//	public static final String P_LANGUAGE = "011:Language";
	public static final String P_LANGUAGE = "Language";

	private CommonTaxonName commonName;

	private List<Language> languages;
	private String[] languageStrings;
	private int selectedLanguageIndex;
	
	/**
	 * @param element
	 */
	public CommonNamePropertySource(CommonTaxonName commonName) {
		super(commonName);
		
		this.commonName = commonName;
		addDescriptor(P_ID_LANGUAGE);
	}
	
	protected void addDescriptor(String id) {
		super.addDescriptor(id);
		
		if (id.equals(P_ID_LANGUAGE)) {
			descriptors.addElement(
					new ComboBoxPropertyDescriptor(P_ID_LANGUAGE, P_LANGUAGE, 
							getLanguageStringArray()));
		}
	}
	
	/**
	 * @return
	 */
	private String[] getLanguageStringArray() {
		if (languages == null) {
			languages = CdmStore.getLanguages();
			
			int i = 0;
			languageStrings = new String[languages.size()];
			for (Language language : languages) {
				languageStrings[i] = LanguageUtil.getDescription(language);
				if (language.equals(commonName.getLanguage())) {
					selectedLanguageIndex = i;
				}	
				i++;
			}
		}
		return languageStrings;
	}

	public Object getPropertyValue(Object id) {
		
		if (id.equals(P_ID_LANGUAGE)) {
			return selectedLanguageIndex;
		}
		
		return super.getPropertyValue(id);
	}
	
	public void setPropertyValue(Object id, Object value) {
		if (id.equals(P_ID_LANGUAGE)) {
			selectedLanguageIndex = ((Integer) value).intValue();
			commonName.setLanguage(languages.get(selectedLanguageIndex));
		}
		
		super.setPropertyValue(id, value);
	}
}