// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.propertysheet.tabbed;


import org.apache.log4j.Logger;
import org.eclipse.core.runtime.Assert;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.ModifyEvent;
import org.eclipse.swt.events.ModifyListener;
import org.eclipse.swt.events.MouseAdapter;
import org.eclipse.swt.events.MouseEvent;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Text;
import org.eclipse.ui.IWorkbenchPart;
import org.eclipse.ui.forms.widgets.ExpandableComposite;
import org.eclipse.ui.forms.widgets.Section;
import org.eclipse.ui.views.properties.tabbed.AbstractPropertySection;
import org.eclipse.ui.views.properties.tabbed.TabbedPropertySheetPage;

import eu.etaxonomy.cdm.api.conversation.ConversationHolder;
import eu.etaxonomy.cdm.api.conversation.IConversationEnabled;
import eu.etaxonomy.cdm.hibernate.HibernateProxyHelper;
import eu.etaxonomy.cdm.model.name.NonViralName;
import eu.etaxonomy.cdm.model.taxon.TaxonBase;
import eu.etaxonomy.cdm.persistence.hibernate.CdmDataChangeMap;
import eu.etaxonomy.taxeditor.editor.EditorUtil;
import eu.etaxonomy.taxeditor.editor.GroupedComposite;
import eu.etaxonomy.taxeditor.editor.Page;

/**
 * @author n.hoffmann
 * @created 09.06.2009
 * @version 1.0
 */
public abstract class AbstractNamePropertySection extends
		AbstractPropertySection implements IConversationEnabled{
	private static final Logger logger = Logger
			.getLogger(AbstractNamePropertySection.class);
	
	private EditorTabbedPropertySheetPage editorPropertySheetPage;
	
	protected GroupedComposite groupedComposite;
	protected TaxonBase<?> taxonBase;
	protected NonViralName<?> name;
	
	protected Section section;
	
	protected Text cacheText;
	protected Button editCacheButton;

	protected Composite composite;

	protected GridData layoutData;


	/**
	 * 
	 */
    protected ModifyListener listener = new ModifyListener() {
        
        public void modifyText(ModifyEvent arg0) {
        	logger.warn("element modified");
        	// TODO refresh the editor
        	EditorUtil.getActiveEditorPage(Page.NAME).setDirty();
        }
    };

	

    /*
     * (non-Javadoc)
     * @see org.eclipse.ui.views.properties.tabbed.AbstractPropertySection#createControls(org.eclipse.swt.widgets.Composite, org.eclipse.ui.views.properties.tabbed.TabbedPropertySheetPage)
     */
    @Override
    public void createControls(Composite parent, TabbedPropertySheetPage tabbedPropertySheetPage){
    	this.createControls(parent, (EditorTabbedPropertySheetPage) tabbedPropertySheetPage);
    }
    

	/**
	 * 
	 * @param parent
	 * @param editorPropertySheetPage
	 */
	public void createControls(Composite parent, EditorTabbedPropertySheetPage editorPropertySheetPage) {
		// reference to the editor
		this.editorPropertySheetPage = editorPropertySheetPage;
		
		super.createControls(parent, editorPropertySheetPage);
		
		layoutData = new GridData(SWT.FILL, SWT.TOP, true, false);
		
		section = getWidgetFactory().createSection(parent, ExpandableComposite.EXPANDED | ExpandableComposite.TREE_NODE | ExpandableComposite.CLIENT_INDENT);

        Composite layoutComposite = getWidgetFactory().createComposite(section);
        section.setClient(layoutComposite);
        
        layoutComposite.setLayout(new GridLayout(1, false));

		
		Composite cacheComposite = getWidgetFactory().createComposite(layoutComposite);
		cacheComposite.setLayoutData(new GridData(SWT.FILL, SWT.FILL, true, false, 2, 1));
		cacheComposite.setLayout(new GridLayout(2, false));
		
		cacheText = getWidgetFactory().createText(cacheComposite, "");
		cacheText.setEditable(false);
		cacheText.setLayoutData(layoutData);
		
		editCacheButton = getWidgetFactory().createButton(cacheComposite, "Cache Editable", SWT.TOGGLE);
		
		editCacheButton.addMouseListener(new MouseAdapter(){

			/* (non-Javadoc)
			 * @see org.eclipse.swt.events.MouseAdapter#mouseUp(org.eclipse.swt.events.MouseEvent)
			 */
			@Override
			public void mouseUp(MouseEvent e) {
				toggleCacheEditing();
			}
			
		});
		
		composite = getWidgetFactory().createComposite(layoutComposite);
		composite.setLayoutData(layoutData);
        composite.setLayout(new GridLayout(2, false));
	}

	/* (non-Javadoc)
	 * @see org.eclipse.ui.views.properties.tabbed.AbstractPropertySection#refresh()
	 */
	@Override
	public void refresh() {
		super.refresh();
		
		
	}

	/* (non-Javadoc)
	 * @see org.eclipse.ui.views.properties.tabbed.AbstractPropertySection#setInput(org.eclipse.ui.IWorkbenchPart, org.eclipse.jface.viewers.ISelection)
	 */
	@Override
	public void setInput(IWorkbenchPart part, ISelection selection) {
        super.setInput(part, selection);
        Assert.isTrue(selection instanceof IStructuredSelection);
        Object input = ((IStructuredSelection) selection).getFirstElement();
        Assert.isTrue(input instanceof GroupedComposite);

        groupedComposite = (GroupedComposite) input;
        taxonBase = (TaxonBase) groupedComposite.getData();
        
        name = HibernateProxyHelper.deproxy(taxonBase.getName(), NonViralName.class);
	}

	/**
	 * 
	 * @param parent
	 * @return
	 */
	protected Button createSearchButton(Composite parent){
		Button button = getWidgetFactory().createButton(parent, "Browse", SWT.PUSH); 
		button.addMouseListener( new SearchButtonListener());
		return button;
	}
	
	/**
	 * 
	 * @author n.hoffmann
	 * @created 11.06.2009
	 * @version 1.0
	 */
	class SearchButtonListener extends MouseAdapter{

		/* (non-Javadoc)
		 * @see org.eclipse.swt.events.MouseListener#mouseUp(org.eclipse.swt.events.MouseEvent)
		 */
		public void mouseUp(MouseEvent e) {
			logger.warn("Open search dialog");
		}

	}
	
	/**
	 * 
	 */
	protected void toggleCacheEditing() {
		if(cacheText.getEditable()){
			cacheText.setEditable(false);
		}else{
			cacheText.setEditable(true);
		}
		refresh();
	}
	
	/*
	 * (non-Javadoc)
	 * @see eu.etaxonomy.cdm.api.conversation.IConversationEnabled#getConversationHolder()
	 */
	public ConversationHolder getConversationHolder(){
		return editorPropertySheetPage.getConversationHolder();
	}
	
	/* (non-Javadoc)
	 * @see eu.etaxonomy.cdm.persistence.hibernate.ICdmPostDataChangeObserver#update(eu.etaxonomy.cdm.persistence.hibernate.CdmDataChangeMap)
	 */
	public void update(CdmDataChangeMap changeEvents) {
		// TODO 
	}
}
