// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.propertysheet.tabbed;

import org.apache.log4j.Logger;
import org.eclipse.swt.SWT;
import org.eclipse.swt.custom.CCombo;
import org.eclipse.swt.custom.CLabel;
import org.eclipse.swt.events.ModifyEvent;
import org.eclipse.swt.events.ModifyListener;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Text;
import org.eclipse.ui.views.properties.tabbed.TabbedPropertySheetPage;

import eu.etaxonomy.cdm.common.CdmUtils;
import eu.etaxonomy.cdm.model.name.NomenclaturalStatusType;
import eu.etaxonomy.cdm.model.name.Rank;
import eu.etaxonomy.taxeditor.preference.PreferencesUtil;
import eu.etaxonomy.taxeditor.store.CdmStore;

/**
 * @author n.hoffmann
 * @created 05.06.2009
 * @version 1.0
 */
public class NamePropertySection extends AbstractNamePropertySection {
	private static final Logger logger = Logger
			.getLogger(NamePropertySection.class);


	private CCombo rankCombo;
	
	private Text uninomialText;
	private Text infragenericEpithetText;
	private Text specificEpithetText;
	private Text infraSpecificEpithetText;
	private Text appendedPhraseText;

	private CCombo nomenclaturalStatusCombo;
	
    protected ModifyListener listener = new ModifyListener() {
        
        public void modifyText(ModifyEvent arg0) {
        	logger.warn("element modified");
        	
        	// FIXME this is a workaround because cache do not get generated on change of underlying data
        	// remove once this is fixed in library
        	name.setAuthorshipCache(null,false);
        	name.setNameCache(null, false);
        	// workaround end
        	
        	
        	
        	name.setGenusOrUninomial(uninomialText.getText());
        	
        	// TODO refresh the editor
        	//EditorUtil.getActiveEditorPage(Page.NAME).setDirty();
        	//EditorUtil.getActiveEditorPage(Page.NAME).redraw(false);
        	groupedComposite.refresh();
        }
    };
	

    @Override
	public void createControls(Composite parent, TabbedPropertySheetPage editorPropertySheetPage){
		super.createControls(parent, editorPropertySheetPage);
//    	super.createControls(parent, tabbedPropertySheetPage);
		
		GridData textFieldLayout = new GridData(SWT.FILL, SWT.FILL, true, true);
		GridData comboLayout = new GridData(SWT.FILL, SWT.FILL, true, false);
		
		// rank
		CLabel rankComboLabel = getWidgetFactory().createCLabel(composite, "Rank:");
		rankCombo = getWidgetFactory().createCCombo(composite);
		rankCombo.setLayoutData(comboLayout);
		
		for (Rank rank : PreferencesUtil.getPreferredRanks()){
			rankCombo.add(rank.getLabel(CdmStore.getDefaultLanguage())); 
		}

		// uninomial
		CLabel uninomialLabel = getWidgetFactory().createCLabel(composite, "Uninomial");
		uninomialText = getWidgetFactory().createText(composite, "");
		uninomialText.setLayoutData(textFieldLayout);
		
		// infrageneric epithet
		CLabel  infragenericEpithetLabel = getWidgetFactory().createCLabel(composite, "Infrageneric Epithet");
		infragenericEpithetText = getWidgetFactory().createText(composite, "");
		infragenericEpithetText.setLayoutData(textFieldLayout);
		
		// specific epithet
		CLabel  specificEpithetLabel = getWidgetFactory().createCLabel(composite, "Specific Epithet");
		specificEpithetText = getWidgetFactory().createText(composite, "");
		specificEpithetText.setLayoutData(textFieldLayout);
		
		// infraspecific epithet
		CLabel  infraspecificEpithetLabel = getWidgetFactory().createCLabel(composite, "Infraspecific Epithet");
		infraSpecificEpithetText = getWidgetFactory().createText(composite, "");
		infraSpecificEpithetText.setLayoutData(textFieldLayout);
		
		// appended phrase
		CLabel  appendedPhraseLabel = getWidgetFactory().createCLabel(composite, "Appended Phrase");
		appendedPhraseText = getWidgetFactory().createText(composite, "");
		appendedPhraseText.setLayoutData(textFieldLayout);
		
		// nomenclatural status
		CLabel nomenclaturalStatusLabel = getWidgetFactory().createCLabel(composite, "Nomenclatural Status", SWT.NO_BACKGROUND);
		nomenclaturalStatusCombo = getWidgetFactory().createCCombo(composite);
		nomenclaturalStatusCombo.setLayoutData(comboLayout);
		
		for(NomenclaturalStatusType nomenclaturalStatusType : CdmStore.getNomenclaturalStatusTypes()){
			nomenclaturalStatusCombo.add(nomenclaturalStatusType.getLabel(CdmStore.getDefaultLanguage()));
		}
        
	}

	/* (non-Javadoc)
	 * @see org.eclipse.ui.views.properties.tabbed.AbstractPropertySection#refresh()
	 */
	@Override
	public void refresh() {
		super.refresh();
		
		section.setText("Name");
		
		cacheText.removeModifyListener(listener);
		cacheText.setText(CdmUtils.Nz(name.getNameCache()));
		cacheText.addModifyListener(listener);
		
		editCacheButton.setSelection(name.isProtectedNameCache());
		
		uninomialText.removeModifyListener(listener);
		uninomialText.setText(CdmUtils.Nz(name.getGenusOrUninomial()));
		uninomialText.addModifyListener(listener);
		
		infragenericEpithetText.setText(CdmUtils.Nz(name.getInfraGenericEpithet()));
		specificEpithetText.setText(CdmUtils.Nz(name.getSpecificEpithet()));
		infraSpecificEpithetText.setText(CdmUtils.Nz(name.getInfraSpecificEpithet()));
		
		appendedPhraseText.setText(CdmUtils.Nz(name.getAppendedPhrase()));
		
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.propertysheet.tabbed.AbstractNamePropertySection#toggleCacheEditing()
	 */
	@Override
	protected void toggleCacheEditing() {
		super.toggleCacheEditing();
		
		if(name.isProtectedNameCache()){
			name.setProtectedNameCache(false);
		}else{
			name.setProtectedNameCache(true);
		}
	}
}
