/**
* Copyright (C) 2009 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.propertysheet.type.wizard;

import org.eclipse.core.databinding.observable.list.WritableList;
import org.eclipse.jface.wizard.IWizardPage;
import org.eclipse.jface.wizard.Wizard;

import eu.etaxonomy.cdm.hibernate.HibernateProxyHelper;
import eu.etaxonomy.cdm.model.name.NameTypeDesignation;
import eu.etaxonomy.cdm.model.name.SpecimenTypeDesignation;
import eu.etaxonomy.cdm.model.name.SpecimenTypeDesignationStatus;
import eu.etaxonomy.cdm.model.name.TaxonNameBase;
import eu.etaxonomy.cdm.model.occurrence.Specimen;
import eu.etaxonomy.taxeditor.model.NameUtil;

/**
 * @author p.ciardelli
 * @created 11.02.2009
 * @version 1.0
 */
public class TypeListWizard extends Wizard {

	private TaxonNameBase<?, ?> name;
	private WritableList typeDesignationsList;
	
	/**
	 * @param name
	 */
	public TypeListWizard(TaxonNameBase<?, ?> name) {
		super();
		
		this.name = name;
		this.typeDesignationsList = new WritableList();
		if (name != null) {
			if (NameUtil.isNameSupraSpecific(name)) {
				this.typeDesignationsList.addAll(name.getNameTypeDesignations());
			} else {
				this.typeDesignationsList.addAll(name.getSpecimenTypeDesignations());				
			}
		}
	}

	public void addPages(){
		IWizardPage chooseTypePage = new ListTypeWizardPage(name, typeDesignationsList);
    	addPage(chooseTypePage);
	}
	
	/* (non-Javadoc)
	 * @see org.eclipse.jface.wizard.Wizard#performFinish()
	 */
	@Override
	public boolean performFinish() {
		
		if (name != null) {
			
			if (NameUtil.isNameSupraSpecific(name)) {
				
				// Remove all designations
				for (Object typeDesignation : name.getNameTypeDesignations()) {
					if (typeDesignation instanceof NameTypeDesignation) {
						name.removeTypeDesignation((NameTypeDesignation) typeDesignation);
					}
				}
				
				// Then re-add them from list
				for (Object typeDesignation : typeDesignationsList) {
					if (typeDesignation instanceof NameTypeDesignation) {
						name.addNameTypeDesignation(
								((NameTypeDesignation) typeDesignation).getTypeName(),
								((NameTypeDesignation) typeDesignation).getCitation(),
								((NameTypeDesignation) typeDesignation).getCitationMicroReference(),
								((NameTypeDesignation) typeDesignation).getOriginalNameString(),
								((NameTypeDesignation) typeDesignation).isRejectedType(),
								((NameTypeDesignation) typeDesignation).isConservedType(),
								((NameTypeDesignation) typeDesignation).isLectoType(),
								((NameTypeDesignation) typeDesignation).isNotDesignated(),
								false);
					}				
				}
				
			} else {
			
				// Remove all designations
				for (Object typeDesignation : name.getSpecimenTypeDesignations()) {
					if (typeDesignation instanceof SpecimenTypeDesignation) {
						name.removeTypeDesignation((SpecimenTypeDesignation) typeDesignation);
					}
				}
				
				// Then re-add them from list
				for (Object typeDesignation : typeDesignationsList) {
					if (typeDesignation instanceof SpecimenTypeDesignation) {
						
						SpecimenTypeDesignation specimenTypeDesignation = (SpecimenTypeDesignation) typeDesignation;
						
						Specimen specimen = HibernateProxyHelper.deproxy(
								specimenTypeDesignation.getTypeSpecimen(), Specimen.class);
						
						SpecimenTypeDesignationStatus typeStatus = HibernateProxyHelper.deproxy(
								specimenTypeDesignation.getTypeStatus(), SpecimenTypeDesignationStatus.class);
						
						name.addSpecimenTypeDesignation(
							specimen,
							typeStatus,
							specimenTypeDesignation.getCitation(),
							specimenTypeDesignation.getCitationMicroReference(),
							specimenTypeDesignation.getOriginalNameString(),
							specimenTypeDesignation.isNotDesignated(),
							false);
					}				
				}
			}
		}
		return true;
	}
}