// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.navigation.handler;

import org.apache.log4j.Logger;
import org.eclipse.core.commands.AbstractHandler;
import org.eclipse.core.commands.ExecutionEvent;
import org.eclipse.core.commands.ExecutionException;
import org.eclipse.core.commands.IHandler;
import org.eclipse.core.commands.common.NotDefinedException;
import org.eclipse.core.commands.operations.IUndoableOperation;

import eu.etaxonomy.cdm.model.common.CdmBase;
import eu.etaxonomy.cdm.model.taxon.TaxonNode;
import eu.etaxonomy.cdm.model.taxon.TaxonomicTree;
import eu.etaxonomy.taxeditor.navigation.NavigationUtil;
import eu.etaxonomy.taxeditor.operations.DeleteTaxonNodeOperation;
import eu.etaxonomy.taxeditor.operations.DeleteTaxonomicTreeOperation;

/**
 * @author n.hoffmann
 * @created 06.04.2009
 * @version 1.0
 */
public class DeleteTaxonNodeHandler extends AbstractHandler implements IHandler{
	private static final Logger logger = Logger
			.getLogger(DeleteTaxonNodeHandler.class);

	public Object execute(ExecutionEvent event) throws ExecutionException {
		CdmBase selection = NavigationUtil.getCurrentSelection(event);
				
		IUndoableOperation operation = null;
		try {
			if(selection instanceof TaxonomicTree){
				operation = new DeleteTaxonomicTreeOperation(event.getCommand().getName(), 
						NavigationUtil.getUndoContext(), (TaxonomicTree) selection);
			}else if(selection instanceof TaxonNode){
				operation = new DeleteTaxonNodeOperation(event.getCommand().getName(), 
						NavigationUtil.getUndoContext(), (TaxonNode) selection);
			}
			NavigationUtil.executeOperation(operation);
		} catch (NotDefinedException e) {
			logger.warn("Command name not set");
		}

		return null;
	}
}
