// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.navigation.search;

import org.apache.log4j.Logger;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.FocusEvent;
import org.eclipse.swt.events.FocusListener;
import org.eclipse.swt.events.KeyAdapter;
import org.eclipse.swt.events.KeyEvent;
import org.eclipse.swt.events.MouseAdapter;
import org.eclipse.swt.events.MouseEvent;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Text;
import org.eclipse.ui.IViewPart;
import org.eclipse.ui.IWorkbenchPage;
import org.eclipse.ui.PartInitException;
import org.eclipse.ui.menus.WorkbenchWindowControlContribution;

import eu.etaxonomy.taxeditor.model.Resources;
import eu.etaxonomy.taxeditor.navigation.internal.TaxeditorNavigationPlugin;

/**
 * @author n.hoffmann
 * @created 15.04.2009
 * @version 1.0
 */
public class SearchBar extends WorkbenchWindowControlContribution{
	private static final Logger logger = Logger.getLogger(SearchBar.class);
	private Composite searchComposite;
	private Text searchText;
	private Button searchButton;
	private String srv;
	
	private String defaultText = "Use \"*\" for wildcard searching";

	@Override
	protected Control createControl(Composite parent) {
		//parent.setLayout(new FillLayout());
		
		searchComposite = new Composite(parent, SWT.NONE);
		final GridLayout gridLayout = new GridLayout();
		gridLayout.numColumns = 2;
		gridLayout.marginWidth = 0;
		gridLayout.marginHeight = 0;
		gridLayout.verticalSpacing = 0;
		gridLayout.horizontalSpacing = 0;
		searchComposite.setLayout(gridLayout);
		// FIXME we have this here for debugging purposes, remove color once the layout of the search bar is correct
		searchComposite.setBackground(Resources.getColor(Resources.SEARCH_VIEW_FOREGROUND));
		
		searchText = new Text(searchComposite, SWT.SEARCH);
		GridData gridData = new GridData(SWT.FILL, SWT.FILL, true, true);

		searchText.setLayoutData(gridData);
		searchText.setForeground(Resources.getColor(Resources.SEARCH_VIEW_FOREGROUND));
		searchText.setText(defaultText);

		searchText.addFocusListener(new FocusListener() {

			public void focusGained(FocusEvent e) {
				searchText.setForeground(Resources.getColor(Resources.SEARCH_VIEW_FOCUS));
				searchText.setText("");
			}

			public void focusLost(FocusEvent e) {
				if (searchText.getText() == "") {
					searchText.setForeground(Resources.getColor(Resources.SEARCH_VIEW_FOREGROUND));
					searchText.setText(defaultText);					
				}	
			}
		});
		searchText.addKeyListener(new KeyAdapter() {
			public void keyReleased(KeyEvent e) {
				int key = e.keyCode;
				if (key == SWT.CR) {
					openSearchResultsView(searchText);
				} else {
					setSearchButtonEnabled();
				}
			}
		});
		
		searchButton = new Button(searchComposite, SWT.NONE);
		searchButton.setText("Search");
		searchButton.setEnabled(false);
		searchButton.addMouseListener(new MouseAdapter() {
			
			// Populate search results resultsTable after clicking button
			public void mouseUp(MouseEvent e) {
				openSearchResultsView(searchText);
			}
		});
		return searchComposite;
	}

	protected void setSearchButtonEnabled() {
		if (searchText.getText().length() == 0) {
			searchButton.setEnabled(false);
		} else {
			searchButton.setEnabled(true);			
		}
	}

	private void openSearchResultsView(Text searchText) {
		if(searchText.getText().length() > 0){
			srv += "1";
			logger.info("Opening search results window " + srv);
			try {
				IViewPart resultsView = TaxeditorNavigationPlugin.getDefault().getWorkbench()
					.getActiveWorkbenchWindow().getActivePage().showView(SearchResultView.ID, 
						srv, IWorkbenchPage.VIEW_ACTIVATE);
				((SearchResultView) resultsView).performSearch(searchText.getText());
			} catch (PartInitException e) {
				logger.error("Error opening search result.", e);
			}
		}
	}
}
