// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.datasource.wizard;

import org.eclipse.jface.wizard.IWizardPage;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.KeyEvent;
import org.eclipse.swt.events.KeyListener;
import org.eclipse.swt.events.MouseAdapter;
import org.eclipse.swt.events.MouseEvent;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Group;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Text;

import eu.etaxonomy.cdm.database.ICdmDataSource;


/**
 * @author n.hoffmann
 * @created 19.05.2009
 * @version 1.0
 */
public abstract class CdmDataSourceCredentialsWizardPage extends WizardPage implements KeyListener{

	protected ICdmDataSource dataSource;
	

	protected Text passwordText;
	protected Text databaseNameText;
	protected Text usernameText;
	
	protected Group authenticationGroup;
	protected Group locationGroup;

	protected Composite composite;

	protected Composite parent;
	
	/**
	 * @param pageName
	 */
	protected CdmDataSourceCredentialsWizardPage(String pageName) {
		super(pageName);
	}
	
	/* (non-Javadoc)
	 * @see org.eclipse.jface.dialogs.IDialogPage#createControl(org.eclipse.swt.widgets.Composite)
	 */
	public void createControl(Composite parent) {
		this.parent = parent;
		
		// Create top-level composite 
		
		composite = new Composite(parent, SWT.NONE);
		composite.setLayoutData(new GridData(SWT.FILL, SWT.FILL, true, true, 2, 1));
		GridLayout formLayout = new GridLayout();
		formLayout.numColumns = 2;
		composite.setLayout(formLayout);

		// create a database specific form
		createDatabaseForm();
		
		// create the authentication input fields
		createAuthenticationForm();
		
		// Create composite for buttons
		Composite buttonComposite = new Composite(composite, SWT.NONE);
		buttonComposite.setLayoutData(new GridData(SWT.RIGHT, SWT.CENTER, true, false));
		GridLayout buttonLayout = new GridLayout();
		buttonLayout.numColumns = 2;
		buttonComposite.setLayout(buttonLayout);
		
		// Create test connection button
		Button testButton = new Button(buttonComposite, SWT.NONE);
		testButton.setLayoutData(new GridData(SWT.RIGHT, SWT.CENTER, false, false));
		testButton.setText("Test connection");
		
		// Test connection when button is pressed
		testButton.addMouseListener(new MouseAdapter() {
			public void mouseUp(MouseEvent e) {
				testDbConfiguration();
			}
		});
		
		setControl(composite);
	}
	

	protected void createAuthenticationForm(){
		// Create group composite for authentication data
		authenticationGroup = new Group(composite, SWT.NONE);
		authenticationGroup.setText("Authentication");
		authenticationGroup.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, true, false, 2, 1));
		GridLayout authenticationLayout = new GridLayout();
		authenticationLayout.numColumns = 2;
		authenticationGroup.setLayout(authenticationLayout);
		
		// Create database name label
		Label databaseNameLabel = new Label(authenticationGroup, SWT.NONE);
		databaseNameLabel.setText("Database Name:");

		// Create database name input
		databaseNameText = new Text(authenticationGroup, SWT.BORDER);
		databaseNameText.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, true, false));
		databaseNameText.addKeyListener(this);

		// Create username label
		Label usernameLabel = new Label(authenticationGroup, SWT.NONE);
		usernameLabel.setText("User Name:");
		
		// Create username input
		usernameText = new Text(authenticationGroup, SWT.BORDER);
		usernameText.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, true, false));
		usernameText.addKeyListener(this);
		
		// Create password label
		Label passwordLabel = new Label(authenticationGroup, SWT.NONE);
		passwordLabel.setText("Password:");

		// Create password input
		passwordText = new Text(authenticationGroup, SWT.BORDER);
		passwordText.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, true, false));
		passwordText.addKeyListener(this);
		
		
		if(dataSource != null){
			// initialize text fields
			databaseNameText.setText(getWizard().getDatabase());
			usernameText.setText(getWizard().getUsername());
			passwordText.setText(getWizard().getPassword());
		}
	}
	
	/**
	 * concrete implementation of the test routine for the specific database
	 */
	public abstract void testDbConfiguration();
	
	/**
	 * Form implementation for the specific database
	 */
	public abstract void createDatabaseForm(); 
	
	public abstract void updateLocation();
	
	/**
	 * updates the current datasource with form values
	 */
	public void updateAuthentication(){
		getWizard().setDatabase(databaseNameText.getText());
		getWizard().setUsername(usernameText.getText());
		getWizard().setPassword(passwordText.getText());
	}
	
	public CdmDataSourceWizard getWizard(){
		return (CdmDataSourceWizard) super.getWizard();
	}

	/* (non-Javadoc)
	 * @see org.eclipse.swt.events.KeyListener#keyReleased(org.eclipse.swt.events.KeyEvent)
	 */
	public void keyReleased(KeyEvent e) {
		updateLocation();
		updateAuthentication();
	}
	
	public void keyPressed(KeyEvent e){}

	/* (non-Javadoc)
	 * @see org.eclipse.jface.wizard.WizardPage#getNextPage()
	 */
	@Override
	public IWizardPage getNextPage() {
		return null;
	}	
	
	
}
