// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.datasource.wizard;

import org.eclipse.jface.wizard.Wizard;
import org.eclipse.jface.wizard.WizardPage;

import eu.etaxonomy.cdm.database.CdmDataSource;
import eu.etaxonomy.cdm.database.DatabaseTypeEnum;
import eu.etaxonomy.cdm.database.ICdmDataSource;
import eu.etaxonomy.taxeditor.datasource.CdmDataSourceRepository;

/**
 * @author n.hoffmann
 * @created 18.05.2009
 * @version 1.0
 */
public class CdmDataSourceWizard extends Wizard {
	
	private WizardPage dataSourcePage;

	private ICdmDataSource dataSource;
	
	private DatabaseTypeEnum databaseType;
	private String dataSourceName;
	private String server;
	private int port;
	private String database;
	private String username;
	private String password; 
	
	/**
	 * @param b
	 */
	public CdmDataSourceWizard(ICdmDataSource dataSource) {
		super();
		setForcePreviousAndNextButtons(true);
		
		
		
		if(dataSource != null){
			this.dataSource = dataSource;
			
			setDatabaseType(dataSource.getDatabaseType());
			setDataSourceName(dataSource.getName());
			setServer(dataSource.getServer());
			setPort(dataSource.getPort());
			setDatabase(dataSource.getDatabase());
			setUsername(dataSource.getUsername());
			setPassword(dataSource.getPassword());
		}
	}


	/* (non-Javadoc)
	 * @see org.eclipse.jface.wizard.Wizard#addPages()
	 */
	@Override
	public void addPages() {

		if(dataSource == null){
			dataSourcePage = new CdmDataSourceWizardPage(dataSource);		
		}else{
			if(dataSource.getDatabaseType() == DatabaseTypeEnum.H2){
				dataSourcePage = new CdmDataSourceH2WizardPage(dataSource);
			}else if(dataSource.getDatabaseType() == DatabaseTypeEnum.MySQL){
				dataSourcePage = new CdmDataSourceMySQLWizardPage(dataSource);
			}
			
		}
		
		this.addPage(dataSourcePage);
	}

	/* (non-Javadoc)
	 * @see org.eclipse.jface.wizard.Wizard#performFinish()
	 */
	@Override
	public boolean performFinish() {
		
		CdmDataSource dataSource = null ;
		
		if(databaseType == DatabaseTypeEnum.H2){
			dataSource = CdmDataSource.NewH2EmbeddedInstance(database, username, password);
		}else if(databaseType == DatabaseTypeEnum.MySQL){
			dataSource = CdmDataSource.NewMySqlInstance(server, database, port, username, password);
		}else if(databaseType == DatabaseTypeEnum.SqlServer2005){
			dataSource = CdmDataSource.NewSqlServer2005Instance(server, database, port, username, password);
		}
					
		CdmDataSourceRepository.getDefault().save(dataSource);
		
		return true;
	}


	/**
	 * @return the dataSource
	 */
	public ICdmDataSource getDataSource() {
		return dataSource;
	}


	/**
	 * @param dataSource the dataSource to set
	 */
	public void setDataSource(ICdmDataSource dataSource) {
		this.dataSource = dataSource;
	}


	/**
	 * @return the databaseType
	 */
	public DatabaseTypeEnum getDatabaseType() {
		return databaseType;
	}


	/**
	 * @param databaseType the databaseType to set
	 */
	public void setDatabaseType(DatabaseTypeEnum databaseType) {
		this.databaseType = databaseType;
	}


	/**
	 * @return the dataSourceName
	 */
	public String getDataSourceName() {
		return dataSourceName;
	}


	/**
	 * @param dataSourceName the dataSourceName to set
	 */
	public void setDataSourceName(String dataSourceName) {
		this.dataSourceName = dataSourceName;
	}


	/**
	 * @return the server
	 */
	public String getServer() {
		return server;
	}


	/**
	 * @param server the server to set
	 */
	public void setServer(String server) {
		this.server = server;
	}


	/**
	 * @return the port
	 */
	public int getPort() {
		return port;
	}


	/**
	 * @param port the port to set
	 */
	public void setPort(int port) {
		this.port = port;
	}


	/**
	 * @return the database
	 */
	public String getDatabase() {
		return database;
	}


	/**
	 * @param database the database to set
	 */
	public void setDatabase(String database) {
		this.database = database;
	}


	/**
	 * @return the username
	 */
	public String getUsername() {
		return username;
	}


	/**
	 * @param username the username to set
	 */
	public void setUsername(String username) {
		this.username = username;
	}


	/**
	 * @return the password
	 */
	public String getPassword() {
		return password;
	}


	/**
	 * @param password the password to set
	 */
	public void setPassword(String password) {
		this.password = password;
	}

}
