// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.datasource.wizard;

import java.util.ArrayList;

import org.eclipse.jface.wizard.IWizardPage;
import org.eclipse.jface.wizard.Wizard;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.KeyEvent;
import org.eclipse.swt.events.KeyListener;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Combo;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Text;

import eu.etaxonomy.cdm.database.DatabaseTypeEnum;
import eu.etaxonomy.cdm.database.ICdmDataSource;

/**
 * @author n.hoffmann
 * @created 18.05.2009
 * @version 1.0
 */
public class CdmDataSourceWizardPage extends WizardPage implements KeyListener{
	
	
	private ArrayList<DatabaseTypeEnum> databaseTypes;
	
	private Text datasourceNameText;
	private Combo databaseTypeCombo;
	
	private Composite composite;
	private Composite editDatasourceComposite;


	private ICdmDataSource dataSource;

	private WizardPage nextPage;
	
	protected CdmDataSourceWizardPage(ICdmDataSource dataSource) {
		super("DataSourceWizardPage");
		
		this.dataSource = dataSource;
		
		String pageName = dataSource == null ? "Create New Datasource" : "Edit Existing Datasource";
		
		setTitle(pageName);
	}

	/* (non-Javadoc)
	 * @see org.eclipse.jface.dialogs.IDialogPage#createControl(org.eclipse.swt.widgets.Composite)
	 */
	public void createControl(Composite parent) {

		// Create top-level composite 
		composite = new Composite(parent, SWT.NONE);
		GridLayout gridLayout = new GridLayout();
		gridLayout.numColumns = 1;
		composite.setLayout(gridLayout);

		// Create editDatasourceComposite to display a dataSource's name and type
		editDatasourceComposite = new Composite(composite, SWT.NONE);
		GridData datasourceGridData = new GridData(SWT.FILL, SWT.TOP, true, true);
		editDatasourceComposite.setLayoutData(datasourceGridData);
		GridLayout datasourceLayout = new GridLayout();
		datasourceLayout.numColumns = 2;
		editDatasourceComposite.setLayout(datasourceLayout);
		
		// Create label and input for dataSource name
		Label datasourceNameLabel = new Label(editDatasourceComposite, SWT.NONE);
		datasourceNameLabel.setText("Datasource Name:");
		datasourceNameText = new Text(editDatasourceComposite, SWT.BORDER);
		datasourceNameText.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, true, false));
		datasourceNameText.addKeyListener(this);

		// Create label and dropdown for database type		
		Label databaseTypeLabel = new Label(editDatasourceComposite, SWT.NONE);
		databaseTypeLabel.setText("Database Type:");
		databaseTypeCombo = new Combo(editDatasourceComposite, SWT.BORDER);
		GridData comboLayout = new GridData(SWT.FILL, SWT.CENTER, false, false);
		databaseTypeCombo.setLayoutData(comboLayout);
		populateComboBoxItems();	
		
		// Create listener to display database type-specific config options
		databaseTypeCombo.addSelectionListener(new SelectionAdapter() {
			public void widgetSelected(SelectionEvent e) {
				
				// Get database type at the selected index
				DatabaseTypeEnum type = databaseTypes.get(databaseTypeCombo.getSelectionIndex());
				
				((CdmDataSourceWizard) getWizard()).setDatabaseType(type);
				
				
				addDatabasePage(type);
			}
		});

		// make the composite the wizard pages control
		setControl(composite);
	}
	
	private void populateComboBoxItems() {
		
		// Init DB types
		if (databaseTypes == null) {
			databaseTypes = new ArrayList<DatabaseTypeEnum>();
		}
		
		// Add types to the type drop-down and to the types collection
		for (DatabaseTypeEnum type : DatabaseTypeEnum.getAllTypes()) {
			// FIXME right now we filter supported types
			if(type.equals(DatabaseTypeEnum.MySQL)
				|| type.equals(DatabaseTypeEnum.H2)
				|| type.equals(DatabaseTypeEnum.SqlServer2005)){
				databaseTypeCombo.add(type.getName());
				databaseTypes.add(type);
			}
		}
	}
	
	/**
	 * @param type
	 */
	private void addDatabasePage(DatabaseTypeEnum type) {
		// add credentials wizard page according to selection
		Wizard wizard = (Wizard) getWizard();
		WizardPage wizardPage = null;
		if(type == DatabaseTypeEnum.H2){
			wizardPage = new CdmDataSourceH2WizardPage(dataSource);
		}else if(type == DatabaseTypeEnum.MySQL){
			wizardPage = new CdmDataSourceMySQLWizardPage(dataSource);
		}else if(type == DatabaseTypeEnum.SqlServer2005){
			wizardPage = new CdmDataSourceSQLServerWizardPage(dataSource);
		}
		
		if(wizard.getPage(wizardPage.getName()) != null){
			nextPage = (WizardPage) wizard.getPage(wizardPage.getName());
		}else{
			wizard.addPage(wizardPage);
			nextPage = wizardPage;
		}
		
//		nextPage = (WizardPage) wizard.getPage(wizardPage.getName());
//		
//		wizard.addPage(wizardPage);
		getContainer().updateButtons();
	}


	/* (non-Javadoc)
	 * @see org.eclipse.swt.events.KeyListener#keyPressed(org.eclipse.swt.events.KeyEvent)
	 */
	public void keyPressed(KeyEvent e) {}

	/* (non-Javadoc)
	 * @see org.eclipse.swt.events.KeyListener#keyReleased(org.eclipse.swt.events.KeyEvent)
	 */
	public void keyReleased(KeyEvent e) {
		((CdmDataSourceWizard) getWizard()).setDataSourceName(datasourceNameText.getText());
	}

	/* (non-Javadoc)
	 * @see org.eclipse.jface.wizard.WizardPage#getNextPage()
	 */
	@Override
	public IWizardPage getNextPage() {
		return nextPage;
	}
	
	
}
