// $Id$
/**
 * Copyright (C) 2007 EDIT
 * European Distributed Institute of Taxonomy 
 * http://www.e-taxonomy.eu
 * 
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * See LICENSE.TXT at the top of this package for the full license terms.
 */

package eu.etaxonomy.taxeditor.dialogs;

import org.apache.log4j.Logger;
import org.eclipse.jface.dialogs.Dialog;
import org.eclipse.swt.SWT;
import org.eclipse.swt.custom.CLabel;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.swt.widgets.Text;
import org.springframework.security.BadCredentialsException;
import org.springframework.security.providers.UsernamePasswordAuthenticationToken;

import eu.etaxonomy.taxeditor.store.CdmStore;

/**
 * @author n.hoffmann
 * @created 16.06.2009
 * @version 1.0
 */
public class LoginDialog extends Dialog {


	private static final Logger logger = Logger.getLogger(LoginDialog.class);

	private static Text passwordText;
	private static Text usernameText;

	/**
	 * @param parentShell
	 */
	public LoginDialog(Shell parentShell) {
		super(parentShell);
	}
		

	/* (non-Javadoc)
	 * @see org.eclipse.jface.dialogs.Dialog#createDialogArea(org.eclipse.swt.widgets.Composite)
	 */
	@Override
	protected Control createDialogArea(Composite parent) {
		Composite composite = (Composite) super.createDialogArea(parent);
		//add controls to composite as necessary
		

		// Label for the heading
		final CLabel titleLabel = new CLabel(composite, SWT.NONE);
		titleLabel.setText("User Login");

		// Label for the username
		final CLabel userNameLabel = new CLabel(composite, SWT.NONE);
		userNameLabel.setText("Username");

		// Textfield for the username
		usernameText = new Text(composite, SWT.BORDER);
		usernameText.setLayoutData(new GridData(SWT.FILL, SWT.FILL, true, true));

		// Label for the password
		final CLabel passwordLabel = new CLabel(composite, SWT.NONE);
		passwordLabel.setText("Password");

		// Textfield for the password
		passwordText = new Text(composite, SWT.BORDER);
		passwordText.setEchoChar('*');
		passwordText.setLayoutData(new GridData(SWT.FILL, SWT.FILL, true, true));
		
		
		return composite;
	}


	/* (non-Javadoc)
	 * @see org.eclipse.jface.dialogs.Dialog#okPressed()
	 */
	@Override
	protected void okPressed() {
		
		String username = usernameText.getText().trim();
		String password = passwordText.getText().trim();
		
		// password is stored as salted md5 hash
		String passwordHash = password;
		
		UsernamePasswordAuthenticationToken token = new UsernamePasswordAuthenticationToken(username, passwordHash); 
		
		try{
			CdmStore.getAuthenticationManager().authenticate(token);
		}catch(BadCredentialsException e){
			logger.error("Bad credentials");
		}catch(IllegalArgumentException e){
			logger.error("Null argument for either user or password");
		}
		
		super.okPressed();
	}	
	
	
}
