// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.io;

import java.io.File;

import org.apache.log4j.Logger;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.Status;
import org.eclipse.core.runtime.jobs.Job;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.jface.wizard.Wizard;
import org.eclipse.ui.IExportWizard;
import org.eclipse.ui.IWorkbench;

import eu.etaxonomy.cdm.io.common.CdmDefaultExport;
import eu.etaxonomy.cdm.io.common.ICdmExporter;
import eu.etaxonomy.cdm.io.jaxb.JaxbExportConfigurator;
import eu.etaxonomy.taxeditor.datasource.CdmDataSourceRepository;
import eu.etaxonomy.taxeditor.store.CdmStore;

/**
 * @author n.hoffmann
 * @created 15.06.2009
 * @version 1.0
 */
public class JaxbExportWizard extends Wizard implements IExportWizard {
	private static final Logger logger = Logger
			.getLogger(JaxbExportWizard.class);

	public final String JAXB_EXPORT = "JAXB_EXPORT";

	private ICdmExporter export;

	private JaxbExportWizardPage page;

	private JaxbExportConfigurator exportConfigurator;
	
	/* (non-Javadoc)
	 * @see org.eclipse.jface.wizard.Wizard#performFinish()
	 */
	@Override
	public boolean performFinish() {
		
		export = new CdmDefaultExport();
		
		String url = page.getFolderText() + File.pathSeparator + page.getExportFileName();
		
		exportConfigurator = JaxbExportConfigurator.NewInstance(CdmDataSourceRepository.getDefault().getCurrentDataSource(), url);
		exportConfigurator.setCdmAppController(CdmStore.getApplicationController());
		
		
		Job exportJob = new Job("JAXB Export"){
			@Override
			protected IStatus run(IProgressMonitor monitor) {
				return export.invoke(exportConfigurator) ? Status.OK_STATUS : Status.CANCEL_STATUS;
			}
		}; 		
		
		exportJob.schedule();
		
		return true;
	}

	/* (non-Javadoc)
	 * @see org.eclipse.ui.IWorkbenchWizard#init(org.eclipse.ui.IWorkbench, org.eclipse.jface.viewers.IStructuredSelection)
	 */
	public void init(IWorkbench workbench, IStructuredSelection selection) {
	}

	/* (non-Javadoc)
	 * @see org.eclipse.jface.wizard.Wizard#addPages()
	 */
	@Override
	public void addPages() {
		super.addPages();
		
		page = new JaxbExportWizardPage(JAXB_EXPORT);
		
		addPage(page);
	}

	

}
