// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.model;

import org.apache.log4j.Logger;

import eu.etaxonomy.cdm.model.common.Language;
import eu.etaxonomy.cdm.model.description.CommonTaxonName;
import eu.etaxonomy.cdm.model.description.DescriptionElementBase;
import eu.etaxonomy.cdm.model.description.Distribution;
import eu.etaxonomy.cdm.model.description.TextData;

/**
 * @author p.ciardelli
 * @created 02.04.2009
 * @version 1.0
 */
public class DescriptionUtil {
	private static final Logger logger = Logger
			.getLogger(DescriptionUtil.class);

	/**
	 * Returns whatever the element's title cache equivalent is,
	 * depending on its class.
	 * 
	 * @param element
	 * @param language
	 * @return 
	 */
	public static String getCache(DescriptionElementBase element, 
			Language language) {
		String cache = null;
		if (element instanceof TextData) {
			cache = ((TextData) element).getText(language);
		}
		if (element instanceof CommonTaxonName) {
			cache = ((CommonTaxonName) element).getName();
		}
		return cache == null ? "" : cache;
	}

	/**
	 * Returns whatever the element's title cache equivalent is,
	 * depending on its class, using the default language.
	 * 
	 * @param element
	 * @return 
	 */
	public static String getCache(DescriptionElementBase element) {
		return getCache(element, Language.DEFAULT());
	}
	
	/**
	 * Set whatever the element's title cache equivalent is,
	 * depending on its class.
	 * 
	 * @param element
	 * @param value
	 * @param language
	 */
	public static void setCache(DescriptionElementBase element,
			String value, Language language) {
		if (element instanceof TextData) {
			((TextData) element).putText(value, language);
			return;
		}
		if (element instanceof CommonTaxonName) {
			((CommonTaxonName) element).setName(value);
			return;
		}
		if(element instanceof Distribution){
			logger.warn("trying to set cache on distribution, don't know what to do at the moment.");
			return;
		}
		logger.warn("No matching subclass found for DescriptionElementBase object, 'cache' not set.");
	}
	
	/**
	 * Set whatever the element's title cache equivalent is,
	 * depending on its class, using the default language.
	 * 
	 * @param element
	 * @param value
	 */	
	public static void setCache(DescriptionElementBase element,
			String value) {
		setCache(element, value, Language.DEFAULT());
	}
}
