// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.model;

import java.util.SortedSet;

import eu.etaxonomy.cdm.model.name.NameRelationshipType;
import eu.etaxonomy.cdm.model.name.NomenclaturalCode;
import eu.etaxonomy.taxeditor.preference.PreferencesUtil;
import eu.etaxonomy.taxeditor.store.CdmStore;

/**
 * @author p.ciardelli
 * @created 30.04.2009
 * @version 1.0
 */
public class NameRelationsUtil {
	
	/**
	 * Get the type's label out of the session's name relations vocabulary, not directly
	 * from the object. 
	 * 
	 * @param type
	 * @return
	 */
	public static String getNameRelationTypeLabel(NameRelationshipType type) {
		boolean isZoological = 
			PreferencesUtil.getPreferredNomenclaturalCode() 
					== NomenclaturalCode.ICZN ?	true : false;
		return getNameRelationTypeLabel(type, isZoological);
	}
	
	public static String getNameRelationTypeLabel(NameRelationshipType type, boolean isZoological) {

		SortedSet<NameRelationshipType> vocab = 
				CdmStore.getDefault().getNameRelationshipTypes();
		
//		SortedSet<NameRelationshipType> vocab = 
//				CdmSessionDataRepository.getDefault().getNameRelationshipTypes();
		for (NameRelationshipType type1 : vocab) {
			if (type1.equals(type)) {
				
				if (isZoological && 
						type1.equals(NameRelationshipType.BASIONYM())) {
					return "original combination for";
				} else {
					return type1.getLabel();
				}
			}
		}
		return "";
	}

	/**
	 * Get the inverse representation of the type out of the session's 
	 * name relations vocabulary, not directly from the object. 
	 * 
	 * @param type
	 * @return
	 */
	public static String getNameRelationInverseTypeLabel(NameRelationshipType type) {
		boolean isZoological = 
			PreferencesUtil.getPreferredNomenclaturalCode() 
					== NomenclaturalCode.ICZN ?	true : false;
		return getNameRelationInverseTypeLabel(type, isZoological);
	}
	
	public static String getNameRelationInverseTypeLabel(NameRelationshipType type, boolean isZoological) {

		SortedSet<NameRelationshipType> vocab = 
				CdmStore.getDefault().getNameRelationshipTypes();
		
//		SortedSet<NameRelationshipType> vocab = 
//				CdmSessionDataRepository.getDefault().getNameRelationshipTypes();
		for (NameRelationshipType type1 : vocab) {
			if (type1.equals(type)) {
				return type1.getInverseLabel();
			}
		}
		return "";
	}
}
