/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.operations;

import org.eclipse.core.commands.ExecutionException;
import org.eclipse.core.commands.operations.IUndoContext;
import org.eclipse.core.runtime.IAdaptable;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.IStatus;

import eu.etaxonomy.cdm.model.name.HomotypicalGroup;
import eu.etaxonomy.cdm.model.name.TaxonNameBase;
import eu.etaxonomy.cdm.model.taxon.Synonym;
import eu.etaxonomy.cdm.model.taxon.SynonymRelationshipType;
import eu.etaxonomy.cdm.model.taxon.Taxon;
import eu.etaxonomy.cdm.model.taxon.TaxonRelationship;
import eu.etaxonomy.cdm.model.taxon.TaxonRelationshipType;
import eu.etaxonomy.taxeditor.model.TaxonUtil;

/**
 * @author p.ciardelli
 * @created 15.01.2009
 * @version 1.0
 * @author n.hoffmann
 */
public class ChangeConceptToSynonymOperation extends
		AbstractPostOperation {
	
	private Taxon concept;

	private HomotypicalGroup homotypicalGroup;

	private TaxonRelationship taxonRelationship;
	private TaxonRelationshipType oldRelationshipType;

	public ChangeConceptToSynonymOperation(String label,
			IUndoContext undoContext, Taxon taxon, Taxon concept, HomotypicalGroup homotypicalGroup,
			IPostOperationEnabled editor) {
		super(label, undoContext, taxon, editor);
		
		this.taxonRelationship = TaxonUtil.getRelationshipBetweenTwoTaxa(concept, taxon);
		this.oldRelationshipType = taxonRelationship.getType();
		
		this.concept = concept;
		this.homotypicalGroup = homotypicalGroup;
	}

	/* (non-Javadoc)
	 * @see org.eclipse.core.commands.operations.AbstractOperation#execute(org.eclipse.core.runtime.IProgressMonitor, org.eclipse.core.runtime.IAdaptable)
	 */
	@Override
	public IStatus execute(IProgressMonitor monitor, IAdaptable info)
			throws ExecutionException {
		
		// Create new synonym using concept name
		TaxonNameBase<?, ?> synonymName = concept.getName();
		Synonym synonym = Synonym.NewInstance(synonymName, taxon.getSec());
		
		// Remove concept relation from taxon
		taxon.removeTaxon(concept, oldRelationshipType);

		
		if(homotypicalGroup != null){
//			// Add synonym to homotypical group
//			homotypicalGroup.addTypifiedName(synonymName);
//			
			if (homotypicalGroup.equals(taxon.getHomotypicGroup())) {
				 taxon.addHomotypicSynonym(synonym, null, null);
			} else {
				taxon.addHeterotypicSynonymName(synonymName, homotypicalGroup, null, null);
			}
		} else {
			taxon.addSynonym(synonym, SynonymRelationshipType.SYNONYM_OF());			
		}
		
		return postExecute(synonym);
	}

	/* (non-Javadoc)
	 * @see org.eclipse.core.commands.operations.AbstractOperation#redo(org.eclipse.core.runtime.IProgressMonitor, org.eclipse.core.runtime.IAdaptable)
	 */
	@Override
	public IStatus redo(IProgressMonitor monitor, IAdaptable info)
			throws ExecutionException {
		// TODO redo for change misapplied name ...
		return null;
	}

	/* (non-Javadoc)
	 * @see org.eclipse.core.commands.operations.AbstractOperation#undo(org.eclipse.core.runtime.IProgressMonitor, org.eclipse.core.runtime.IAdaptable)
	 */
	@Override
	public IStatus undo(IProgressMonitor monitor, IAdaptable info)
			throws ExecutionException {
		// TODO undo for change misapplied name ...
		return null;
	}
}
