/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.operations;

import java.util.UUID;

import org.apache.log4j.Logger;
import org.eclipse.core.commands.ExecutionException;
import org.eclipse.core.commands.operations.IUndoContext;
import org.eclipse.core.runtime.IAdaptable;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.Status;

import eu.etaxonomy.cdm.api.conversation.ConversationHolder;
import eu.etaxonomy.cdm.model.reference.ReferenceBase;
import eu.etaxonomy.cdm.model.taxon.Synonym;
import eu.etaxonomy.cdm.model.taxon.Taxon;
import eu.etaxonomy.cdm.model.taxon.TaxonNode;
import eu.etaxonomy.taxeditor.model.TaxonUtil;
import eu.etaxonomy.taxeditor.store.CdmStore;

/**
 * Change the taxonomic parent of a given taxon.
 * 
 * @author n.hoffmann
 * @created 16.01.2009
 * @version 1.0
 */
public class MoveTaxonOperation extends AbstractPostOperation {
	
	@SuppressWarnings("unused")
	private static final Logger logger = Logger.getLogger(MoveTaxonOperation.class);
	/**
	 * A reference to the new taxonomical parent.
	 */
	private TaxonNode newParentTaxonNode;
	/**
	 * A reference to the former taxonomical parent
	 */
	private TaxonNode oldParentTaxonNode;

	public MoveTaxonOperation(String label, IUndoContext undoContext,
			TaxonNode taxonNode, TaxonNode newParentTaxonNode, IPostOperationEnabled postOperationEnabled) {
		super(label, undoContext, taxonNode, null);

		this.newParentTaxonNode = newParentTaxonNode;
		
		// Save old parent TaxonNode for undo
		this.oldParentTaxonNode = taxonNode.getParent(); 
	}
	
	/* (non-Javadoc)
	 * @see org.eclipse.core.commands.operations.AbstractOperation#execute(org.eclipse.core.runtime.IProgressMonitor, org.eclipse.core.runtime.IAdaptable)
	 */
	@Override
	public IStatus execute(IProgressMonitor monitor, IAdaptable info)
			throws ExecutionException {
		
		TaxonNode newTaxonNode = moveTaxonBaseIsolated(taxonNode.getUuid(), newParentTaxonNode.getUuid());
		
		return postExecute(newTaxonNode);
	}

	/* (non-Javadoc)
	 * @see org.eclipse.core.commands.operations.AbstractOperation#redo(org.eclipse.core.runtime.IProgressMonitor, org.eclipse.core.runtime.IAdaptable)
	 */
	@Override
	public IStatus redo(IProgressMonitor monitor, IAdaptable info)
			throws ExecutionException {
		return execute(monitor, info);
	}

	/* (non-Javadoc)
	 * @see org.eclipse.core.commands.operations.AbstractOperation#undo(org.eclipse.core.runtime.IProgressMonitor, org.eclipse.core.runtime.IAdaptable)
	 */
	@Override
	public IStatus undo(IProgressMonitor monitor, IAdaptable info)
			throws ExecutionException {
		
		moveTaxonBaseIsolated(taxonNode.getUuid(), oldParentTaxonNode.getUuid());
		
		return Status.OK_STATUS;
	}
	
	/**
	 * 
	 * @param taxonNodeUuid
	 * @param newParentTaxonNodeUuid
	 * @return
	 */
	private TaxonNode moveTaxonBaseIsolated(UUID taxonNodeUuid, UUID newParentTaxonNodeUuid){
		
		// get a new conversation
		ConversationHolder conversation = CdmStore.NewTransactionalConversation();
		// find the taxon node
		TaxonNode taxonNode = CdmStore.getTaxonService().getTaxonNodeByUuid(taxonNodeUuid);
		// store all relevant information of taxon node and delete the taxon node.
		Taxon taxon = taxonNode.getTaxon();
		ReferenceBase parentChildReference = taxonNode.getReferenceForParentChildRelation();
		String parentChildMicroReference = taxonNode.getMicroReferenceForParentChildRelation();
		Synonym synonymUsed = taxonNode.getSynonymToBeUsed();

		taxonNode.remove();
		
		TaxonNode newParentTaxonNode = CdmStore.getTaxonService().getTaxonNodeByUuid(newParentTaxonNodeUuid);
		TaxonNode newChild = newParentTaxonNode.addChild(taxon, parentChildReference, parentChildMicroReference, synonymUsed);
		// commit the conversation
		conversation.commit(true);		
		return newChild;
	}
}
