// $Id$
/**
 * Copyright (C) 2007 EDIT
 * European Distributed Institute of Taxonomy 
 * http://www.e-taxonomy.eu
 * 
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * See LICENSE.TXT at the top of this package for the full license terms.
 */

package eu.etaxonomy.taxeditor.preference;

import java.util.HashMap;
import java.util.List;
import java.util.Set;

import org.eclipse.jface.preference.PreferencePage;
import org.eclipse.jface.viewers.CheckboxTableViewer;
import org.eclipse.jface.viewers.IStructuredContentProvider;
import org.eclipse.jface.viewers.ITableLabelProvider;
import org.eclipse.jface.viewers.LabelProvider;
import org.eclipse.jface.viewers.Viewer;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.MouseAdapter;
import org.eclipse.swt.events.MouseEvent;
import org.eclipse.swt.graphics.Image;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.ui.IWorkbench;

import eu.etaxonomy.cdm.model.common.DefinedTermBase;

/**
 * @author n.hoffmann
 * @created 12.06.2009
 * @version 1.0
 */
public abstract class AbstractMenuPreferences extends PreferencePage{

	private Button toggleButton;
	protected HashMap<DefinedTermBase, Button> menuButtons;
	
	protected Set<?> vocabulary;
	
	private List preferedTerms;
	
	protected CheckboxTableViewer tableViewer;
	
	private boolean state = true;

	/**
	 * Constructs a new menu preference page.
	 * 
	 * @param initialVocabulary the initial vocabulary contating all possible entries for the menu
	 * @param preferedTerms a List containtg already prefered terms 
	 * @param title the title of the page
	 * @param description describing text for the preference page
	 */
	public AbstractMenuPreferences(Set<?> initialVocabulary, List preferedTerms, String title, String description) {
		super(title);
		vocabulary = initialVocabulary;
		this.preferedTerms = preferedTerms;
		setDescription(description);
	}

	/**
	 * Create contents of the preference page
	 * @param parent
	 */
	@Override
	public Control createContents(Composite parent) {
		
		Composite container = new Composite(parent, SWT.NULL);
		final GridLayout gridLayout = new GridLayout();
		gridLayout.numColumns = 2;
		container.setLayout(gridLayout);
	
		tableViewer = CheckboxTableViewer.newCheckList(container, SWT.NULL);
		GridData tableLayoutData = new GridData(SWT.FILL, SWT.FILL, true, false);
		tableLayoutData.heightHint = 300;
		tableViewer.getTable().setLayoutData(tableLayoutData);
		
		tableViewer.setContentProvider(new MenuPreferenceContentProvider());
		tableViewer.setLabelProvider(new MenuPreferenceLabelProvider());
			
		tableViewer.setInput(vocabulary);
		
		tableViewer.setCheckedElements(preferedTerms.toArray());
		
		Composite buttonContainer = new Composite(container, SWT.NULL);
		GridData buttonContainerLayoutData = new GridData();
		buttonContainerLayoutData.verticalAlignment = SWT.TOP;
		buttonContainer.setLayoutData(buttonContainerLayoutData);
		buttonContainer.setLayout(new GridLayout());
		
		createButtons(buttonContainer);
		
		toggleButton = new Button(buttonContainer, SWT.PUSH);
		toggleButton.setText("Toggle");
		toggleButton.addMouseListener(new MouseAdapter(){
	
			/* (non-Javadoc)
			 * @see org.eclipse.swt.events.MouseAdapter#mouseDown(org.eclipse.swt.events.MouseEvent)
			 */
			@Override
			public void mouseDown(MouseEvent e) {
				tableViewer.setAllChecked(state);
				state = state ? false : true;
			}			
		});
		
		return container;
	}


	/**
	 * @param buttonContainer
	 */
	protected abstract void createButtons(Composite buttonContainer);

	public void init(IWorkbench workbench) {
		setPreferenceStore(PreferencesUtil.getPrefStore());
	}

	/*
	 * (non-Javadoc)
	 * @see org.eclipse.jface.preference.PreferencePage#performDefaults()
	 */
	protected void performDefaults() {
		tableViewer.setAllChecked(true);
	}
	
	/**
	 * 
	 * @author n.hoffmann
	 * @created 12.06.2009
	 * @version 1.0
	 */
	private class MenuPreferenceContentProvider implements IStructuredContentProvider{

		public Object[] getElements(Object inputElement) {			
			return ((Set<?>) inputElement).toArray(new DefinedTermBase[0]);
		}

		public void dispose() {}

		public void inputChanged(Viewer viewer, Object oldInput,
				Object newInput) {}
		
	};
	
	/**
	 * 
	 * @author n.hoffmann
	 * @created 12.06.2009
	 * @version 1.0
	 */
	private class MenuPreferenceLabelProvider extends LabelProvider implements ITableLabelProvider{

		/* (non-Javadoc)
		 * @see org.eclipse.jface.viewers.ITableLabelProvider#getColumnImage(java.lang.Object, int)
		 */
		public Image getColumnImage(Object element, int columnIndex) {
			return null;
		}

		/* (non-Javadoc)
		 * @see org.eclipse.jface.viewers.ITableLabelProvider#getColumnText(java.lang.Object, int)
		 */
		public String getColumnText(Object element, int columnIndex) {
			return ((DefinedTermBase)element).getLabel();
		}
		
	}

	/**
	 * @return the tableViewer
	 */
	public CheckboxTableViewer getTableViewer() {
		return tableViewer;
	}	
	
}