/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/
package eu.etaxonomy.taxeditor.preference;

import java.util.ArrayList;
import java.util.List;

import org.eclipse.jface.wizard.WizardDialog;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.MouseAdapter;
import org.eclipse.swt.events.MouseEvent;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.ui.IWorkbenchPreferencePage;

import eu.etaxonomy.cdm.model.description.Feature;
import eu.etaxonomy.taxeditor.preference.wizards.FeatureWizard;
import eu.etaxonomy.taxeditor.store.CdmStore;
import eu.etaxonomy.taxeditor.store.StoreUtil;

/**
 * @author p.ciardelli
 * @created 17.09.2008
 * @version 1.0
 * @author n.hoffmann
 */
public class FeatureMenuPreferences extends AbstractMenuPreferences implements
		IWorkbenchPreferencePage {

	public static final String PLUGIN_ID = "eu.etaxonomy.taxeditor.preferences.feature";
	private Button newButton;
	private Button editButton;
	private Button removeButton;
	
	public FeatureMenuPreferences() {
		super(CdmStore.getFeatures(), PreferencesUtil.getPreferredFeatures(), "Feature Preferences", "Choose which features you would like to use for descriptive elements.");
	}

	
	/* (non-Javadoc)
	 * @see org.eclipse.jface.preference.PreferencePage#performOk()
	 */
	public boolean performOk() {
		List<Feature> preferredFeatures = new ArrayList<Feature>();
		for (Object element : getTableViewer().getCheckedElements()){
			preferredFeatures.add((Feature) element);
		}
		
		PreferencesUtil.setPreferredFeatures(preferredFeatures);
		
		return true;
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.preference.AbstractMenuPreferences#createButtons(org.eclipse.swt.widgets.Composite)
	 */
	@Override
	protected void createButtons(Composite buttonContainer) {
		newButton = new Button(buttonContainer, SWT.PUSH);
		newButton.setText("New");
		newButton.setLayoutData(new GridData(SWT.FILL));
		newButton.addMouseListener(new MouseAdapter(){

			/* (non-Javadoc)
			 * @see org.eclipse.swt.events.MouseAdapter#mouseUp(org.eclipse.swt.events.MouseEvent)
			 */
			@Override
			public void mouseUp(MouseEvent e) {
				super.mouseUp(e);
				FeatureWizard wizard = new FeatureWizard(); 
				
				WizardDialog dialog = new WizardDialog(StoreUtil.getShell(), wizard);
			    dialog.open();
			    
			    tableViewer.setInput(CdmStore.getFeatures());
			}
			
		});
		
		editButton = new Button(buttonContainer, SWT.PUSH);
		editButton.setText("Edit");
		editButton.setLayoutData(new GridData(SWT.FILL));
		editButton.addMouseListener(new MouseAdapter(){

			/* (non-Javadoc)
			 * @see org.eclipse.swt.events.MouseAdapter#mouseUp(org.eclipse.swt.events.MouseEvent)
			 */
			@Override
			public void mouseUp(MouseEvent e) {
				super.mouseUp(e);

				StoreUtil.notImplementedMessage();
				
				// editing a feature is somewhat more complicated, because basically one can only edit the representation.
//				Feature feature = (Feature) ((StructuredSelection) tableViewer.getSelection()).getFirstElement();
//				
//				FeatureWizard wizard = new FeatureWizard(feature); 
//				
//				WizardDialog dialog = new WizardDialog(StoreUtil.getShell(), wizard);
//			    dialog.open();
//			    
//			    tableViewer.setInput(CdmStore.getFeatures());
			}
			
		});
		
		removeButton = new Button(buttonContainer, SWT.PUSH);
		removeButton.setText("Remove");
		removeButton.setLayoutData(new GridData(SWT.FILL));
		removeButton.addMouseListener(new MouseAdapter(){

			/* (non-Javadoc)
			 * @see org.eclipse.swt.events.MouseAdapter#mouseUp(org.eclipse.swt.events.MouseEvent)
			 */
			@Override
			public void mouseUp(MouseEvent e) {
				super.mouseUp(e);
				StoreUtil.notImplementedMessage();
			}
			
		});
	}
}
