/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.preference;

import org.eclipse.jface.preference.PreferencePage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.ui.IWorkbench;
import org.eclipse.ui.IWorkbenchPreferencePage;

import eu.etaxonomy.taxeditor.model.Resources;

/**
 * @author p.ciardelli
 * @created 01.07.2008
 * @version 1.0
 */
public class InitializeDbPreferences extends PreferencePage implements
		IWorkbenchPreferencePage {

	public static final String PLUGIN_ID = "eu.etaxonomy.taxeditor.preferences.initdb";

	private Button btnInit;
//	private Button btnTestData;
	
	public InitializeDbPreferences() {
		super();
		setDescription("If you choose this option, taxonomic tree will be empty next time the Editor is started.");
	}

	/**
	 * Create contents of the preference page
	 * @param parent
	 */
	@Override
	public Control createContents(Composite parent) {

		Composite container = new Composite(parent, SWT.NULL);
		container.setLayout(new GridLayout());

		btnInit = new Button(container, SWT.CHECK);
		btnInit.setText("Initialize datastore on next application start");
		btnInit.addSelectionListener(new SelectionAdapter() {

			@Override
			public void widgetSelected(SelectionEvent e) {
				if (btnInit.getSelection() == true) {
					
					// Enable test data option
//					btnTestData.setEnabled(true);
					
				} else {
				
					// Disable test data option, set selected to "false"
//					btnTestData.setEnabled(false);
//					btnTestData.setSelection(false);
				}
			}
			
		});

//		btnTestData = new Button(container, SWT.CHECK);
//		btnTestData.setEnabled(false);
//		final GridData gridData = new GridData();
//		gridData.horizontalIndent = 20;
//		btnTestData.setLayoutData(gridData);
//		btnTestData.setText("Initialize with Palmweb test data");
		
		return container;
	}

	/**
	 * Initialize the preference page
	 */
	public void init(IWorkbench workbench) {
		setPreferenceStore(PreferencesUtil.getPrefStore());
	}
	
	@Override
	protected void performDefaults() {
		btnInit.setSelection(false);
//		btnTestData.setSelection(false);
		super.performDefaults();
	}
	
	@Override	
	public boolean performOk() {
		boolean doReinitialize = !(btnInit.getSelection());
//		boolean doInitTestdata = btnTestData.getSelection();
		
		PreferencesUtil.getPrefStore().setValue(Resources.INITIALIZED, doReinitialize);
//		UiUtil.getPrefStore().setValue(ITaxEditorConstants.INITIALIZE_W_TESTDATA, doInitTestdata);		
		return true;
	}
}
