/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/
package eu.etaxonomy.taxeditor.preference;

import org.eclipse.jface.preference.PreferencePage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.ui.IWorkbench;
import org.eclipse.ui.IWorkbenchPreferencePage;

import eu.etaxonomy.taxeditor.model.Resources;
import eu.etaxonomy.taxeditor.store.internal.TaxeditorStorePlugin;

/**
 * @author p.ciardelli
 * @created 16.09.2008
 * @version 1.0
 */
public class NomenclaturalCodePreferences extends PreferencePage implements
		IWorkbenchPreferencePage {

	public static final String PLUGIN_ID = "eu.etaxonomy.taxeditor.preferences.nomenclatural";

	private Button icznButton;
	private Button icbnButton;	
	
	private String preferredCode;
		
	public NomenclaturalCodePreferences() {
		super();
		setDescription("Choose which nomenclatural code you would like to use for scientific names unless otherwise specified.");
	}

	/**
	 * Create contents of the preference page
	 * @param parent
	 */
	@Override
	public Control createContents(Composite parent) {
		
		
		Composite container = new Composite(parent, SWT.NULL);
		container.setLayout(new GridLayout());

		icbnButton = new Button(container, SWT.RADIO);
		icbnButton.setText("Botanical (ICBN)");
		icbnButton.addSelectionListener(new SelectionAdapter() {
			public void widgetSelected(SelectionEvent e) {
				preferredCode = Resources.CODE_PREFERENCE_ICBN;
			}
		});

		icznButton = new Button(container, SWT.RADIO);
		icznButton.setText("Zoological (ICZN)");
		icznButton.addSelectionListener(new SelectionAdapter() {
			public void widgetSelected(SelectionEvent e) {
				preferredCode = Resources.CODE_PREFERENCE_ICZN;
			}
		});
		
		preferredCode = getPreferenceStore().getString(Resources.CODE_PREFERENCE);
		if (preferredCode == null) {
			getPreferenceStore().setValue(
					Resources.CODE_PREFERENCE, Resources.DEFAULT_CODE_PREFERENCE);
		}
		setButton(preferredCode);		
		
		return container;
	}

	/**
	 * Initialize the preference page
	 */
	public void init(IWorkbench workbench) {
		setPreferenceStore(TaxeditorStorePlugin.getDefault().getPreferenceStore());
	}
	
	protected void performDefaults() {
		setButton(Resources.DEFAULT_CODE_PREFERENCE);
	}
	
	public boolean performOk() {
		getPreferenceStore().setValue(
				Resources.CODE_PREFERENCE, preferredCode);
		return true;
	}
	
	private void setButton(String preferredCode) {
		this.preferredCode = preferredCode;
		
		if (preferredCode.equals(Resources.CODE_PREFERENCE_ICBN)) {		
			icbnButton.setSelection(true);
			icznButton.setSelection(false);
		}
		if (preferredCode.equals(Resources.CODE_PREFERENCE_ICZN)) {
			icbnButton.setSelection(false);
			icznButton.setSelection(true);
		}
	}
}
